Index: src/bp-templates/bp-legacy/buddypress/activity/post-form.php
===================================================================
--- src/bp-templates/bp-legacy/buddypress/activity/post-form.php	(revision 10690)
+++ src/bp-templates/bp-legacy/buddypress/activity/post-form.php	(working copy)
@@ -25,64 +25,87 @@
 		</a>
 	</div>
 
-	<p class="activity-greeting"><?php if ( bp_is_group() )
-		printf( __( "What's new in %s, %s?", 'buddypress' ), bp_get_group_name(), bp_get_user_firstname( bp_get_loggedin_user_fullname() ) );
-	else
-		printf( __( "What's new, %s?", 'buddypress' ), bp_get_user_firstname( bp_get_loggedin_user_fullname() ) );
-	?></p>
+	<div id="whats-new-content">
 
-	<div id="whats-new-content">
 		<div id="whats-new-textarea">
 			<label for="whats-new" class="bp-screen-reader-text"><?php _e( 'Post what\'s new', 'buddypress' ); ?></label>
-			<textarea class="bp-suggestions" name="whats-new" id="whats-new" cols="50" rows="10"
+			<textarea class="bp-suggestions" name="whats-new" id="whats-new" cols="50" rows="1"
 				<?php if ( bp_is_group() ) : ?>data-suggestions-group-id="<?php echo esc_attr( (int) bp_get_current_group_id() ); ?>" <?php endif; ?>
-			><?php if ( isset( $_GET['r'] ) ) : ?>@<?php echo esc_textarea( $_GET['r'] ); ?> <?php endif; ?></textarea>
+			placeholder="<?php echo esc_attr( bp_get_activity_whats_new_placeholder() ) ;?>"><?php if ( isset( $_GET['r'] ) ) : ?>@<?php echo esc_textarea( $_GET['r'] ); ?> <?php endif; ?></textarea>
 		</div>
 
-		<div id="whats-new-options">
-			<div id="whats-new-submit">
-				<input type="submit" name="aw-whats-new-submit" id="aw-whats-new-submit" value="<?php esc_attr_e( 'Post Update', 'buddypress' ); ?>" />
-			</div>
+		<div id="whats-new-actions">
+			<?php
+			/**
+			 * Fires before the activity post form options.
+			 *
+			 * @since BuddyPress (2.4.0)
+			 */
+			do_action( 'bp_activity_post_form_before_options' ); ?>
 
-			<?php if ( bp_is_active( 'groups' ) && !bp_is_my_profile() && !bp_is_group() ) : ?>
+			<div id="whats-new-options">
 
-				<div id="whats-new-post-in-box">
+				<?php if ( bp_is_active( 'groups' ) && !bp_is_my_profile() && !bp_is_group() ) : ?>
 
-					<?php _e( 'Post in', 'buddypress' ); ?>:
+					<div id="whats-new-post-in-box">
 
-					<label for="whats-new-post-in" class="bp-screen-reader-text"><?php _e( 'Post in', 'buddypress' ); ?></label>
-					<select id="whats-new-post-in" name="whats-new-post-in">
-						<option selected="selected" value="0"><?php _e( 'My Profile', 'buddypress' ); ?></option>
+						<label for="whats-new-post-in"><?php _e( 'Post in', 'buddypress' ); ?>:</label>
 
-						<?php if ( bp_has_groups( 'user_id=' . bp_loggedin_user_id() . '&type=alphabetical&max=100&per_page=100&populate_extras=0&update_meta_cache=0' ) ) :
-							while ( bp_groups() ) : bp_the_group(); ?>
+						<select id="whats-new-post-in" name="whats-new-post-in">
+							<option selected="selected" value="0"><?php _e( 'My Profile', 'buddypress' ); ?></option>
 
-								<option value="<?php bp_group_id(); ?>"><?php bp_group_name(); ?></option>
+							<?php if ( bp_has_groups( 'user_id=' . bp_loggedin_user_id() . '&type=alphabetical&max=100&per_page=100&populate_extras=0&update_meta_cache=0' ) ) :
+								while ( bp_groups() ) : bp_the_group(); ?>
 
-							<?php endwhile;
-						endif; ?>
+									<option value="<?php bp_group_id(); ?>"><?php bp_group_name(); ?></option>
 
-					</select>
-				</div>
-				<input type="hidden" id="whats-new-post-object" name="whats-new-post-object" value="groups" />
+								<?php endwhile;
+							endif; ?>
 
-			<?php elseif ( bp_is_group_activity() ) : ?>
+						</select>
+					</div>
+					<input type="hidden" id="whats-new-post-object" name="whats-new-post-object" value="groups" />
 
-				<input type="hidden" id="whats-new-post-object" name="whats-new-post-object" value="groups" />
-				<input type="hidden" id="whats-new-post-in" name="whats-new-post-in" value="<?php bp_group_id(); ?>" />
+				<?php elseif ( bp_is_group_home() ) : ?>
 
-			<?php endif; ?>
+					<input type="hidden" id="whats-new-post-object" name="whats-new-post-object" value="groups" />
+					<input type="hidden" id="whats-new-post-in" name="whats-new-post-in" value="<?php bp_group_id(); ?>" />
 
+				<?php endif; ?>
+
+				<?php
+
+				/**
+				 * Fires at the end of the activity post form options.
+				 *
+				 * @since BuddyPress (1.2.0)
+				 */
+				do_action( 'bp_activity_post_form_options' ); ?>
+
+			</div><!-- #whats-new-options -->
+
 			<?php
-
 			/**
 			 * Fires at the end of the activity post form markup.
 			 *
-			 * @since 1.2.0
+			 * @since BuddyPress (2.4.0)
 			 */
-			do_action( 'bp_activity_post_form_options' ); ?>
+			do_action( 'bp_activity_post_form_before_submit' ); ?>
 
-		</div><!-- #whats-new-options -->
+			<div id="whats-new-submit">
+
+				<input type="reset" name="aw-whats-new-reset" id="aw-whats-new-reset" value="<?php esc_attr_e( 'Cancel', 'buddypress' ); ?>" />
+				<input type="submit" name="aw-whats-new-submit" id="aw-whats-new-submit" value="<?php esc_attr_e( 'Post Update', 'buddypress' ); ?>" />
+
+				 <?php
+				/**
+				 * Fires at the end of the activity post form submit.
+				 *
+				 * @since BuddyPress (2.4.0)
+				 */
+				do_action( 'bp_activity_post_form_submit' ); ?>
+			</div><!-- #whats-new-submit -->
+		</div><!-- #whats-new-actions -->
 	</div><!-- #whats-new-content -->
 
 	<?php wp_nonce_field( 'post_update', '_wpnonce_post_update' ); ?>
@@ -25,64 +25,87 @@
 			/**
-			 * Fires at the end of the activity post form markup.
+			 * Fires before the activity post form submit.
 			 *
